==> artap-2020.3.26.5-py3-none-any.whl: artap/job.py <==
import time
from abc import ABCMeta
from .individual import Individual


class Job(metaclass=ABCMeta):
    def __init__(self, problem, population=None):
        self.problem = problem
        self.population = population

    def evaluate(self, individual):
        # info
        individual.info["start_time"] = time.time()
        t_s = time.time()

        # set in progress
        individual.state = individual.State.IN_PROGRESS

        # check the constraints
        constraints = self.problem.evaluate_constraints(individual)

        if constraints:
            individual.feasible = sum(map(abs, constraints))

        # problem cost function evaluate only in that case when the problem is fits the constraints
        try:
            costs = self.problem.surrogate.evaluate(individual)
            if isinstance(costs, list):
                individual.costs = costs
            else:
                raise AssertionError("Costs type must be list.")

            # set evaluated
            individual.state = individual.State.EVALUATED

        except (TimeoutError, RuntimeError) as e:
            individual.state = Individual.State.FAILED

        # add to population
        if self.population is not None:
            self.population.individuals.append(individual)
            individual.info["population"] = self.problem.populations.index(self.population)

        # info
        individual.info["finish_time"] = time.time()

    def evaluate_scalar(self, x):
        # simple individual
        individual = Individual(x)
        self.evaluate(individual)

        return individual.costs[0]

==> artap-2020.4.25.1-py3-none-any.whl: artap/job.py <==
import time
from abc import ABCMeta
from .individual import Individual
from math import inf

class Job(metaclass=ABCMeta):
    def __init__(self, problem, population=None):
        self.problem = problem
        self.population = population

    def evaluate(self, individual):
        # info
        individual.info["start_time"] = time.time()
        t_s = time.time()

        # set in progress
        individual.state = individual.State.IN_PROGRESS

        # check the constraints
        constraints = self.problem.evaluate_constraints(individual)

        if constraints:
            individual.feasible = sum(map(abs, constraints))

        # problem cost function evaluate only in that case when the problem fits the constraints
        try:
            costs = self.problem.surrogate.evaluate(individual)
            if isinstance(costs, list):
                individual.costs = costs
                if self.problem is not None:
                    individual.calc_signed_costs(self.problem.signs)  # the idea is to make this conversion only once
                #     individual.signs = self.problem.signs
            else:
                raise AssertionError("Costs type must be list.")

            # set evaluated
            individual.state = individual.State.EVALUATED

        except (TimeoutError, RuntimeError) as e:
            individual.state = Individual.State.FAILED
            if individual.feasible == 0.0:
                individual.feasible = inf # TODO: genetic algorithms uses this information, i dont know the correct solution

        # add to population
        if self.population is not None:
            self.population.individuals.append(individual)
            individual.info["population"] = self.problem.populations.index(self.population)

        # info
        individual.info["finish_time"] = time.time()

    def evaluate_scalar(self, x):
        # simple individual
        individual = Individual(x)
        self.evaluate(individual)

        return individual.costs[0]
